import { stats_calculate_similarity, stats_normalize, resample_data } from "../feature_statistics";
import { linear_regression } from "../feature_regression";
import { optimize } from "../feature_optimize";
export const match_ascending_triangle = (sampleOHLC, patternOHLC) => {
    const sampleHigh = stats_normalize(sampleOHLC.map(candle => candle.high));
    const sampleLow = stats_normalize(sampleOHLC.map(candle => candle.low));
    const patternHigh = stats_normalize(patternOHLC.map(candle => candle.high));
    const patternLow = stats_normalize(patternOHLC.map(candle => candle.low));
    const objective = (scale) => {
        const resampledPatternHigh = resample_data(patternHigh, Math.round(sampleHigh.length * scale));
        const resampledPatternLow = resample_data(patternLow, Math.round(sampleLow.length * scale));
        // Pad or truncate the resampled pattern to match the sample length
        const paddedPatternHigh = resampledPatternHigh.length < sampleHigh.length
            ? [...resampledPatternHigh, ...new Array(sampleHigh.length - resampledPatternHigh.length).fill(resampledPatternHigh[resampledPatternHigh.length - 1])]
            : resampledPatternHigh.slice(0, sampleHigh.length);
        const paddedPatternLow = resampledPatternLow.length < sampleLow.length
            ? [...resampledPatternLow, ...new Array(sampleLow.length - resampledPatternLow.length).fill(resampledPatternLow[resampledPatternLow.length - 1])]
            : resampledPatternLow.slice(0, sampleLow.length);
        const similarityHigh = stats_calculate_similarity(sampleHigh, paddedPatternHigh);
        const similarityLow = stats_calculate_similarity(sampleLow, paddedPatternLow);
        // For ascending triangle, we want increasing lows and relatively flat highs
        const lowTrend = linear_regression(sampleLow).slope;
        const highTrend = linear_regression(sampleHigh).slope;
        const triangleScore = lowTrend - Math.abs(highTrend);
        return -(similarityHigh + similarityLow + triangleScore);
    };
    // Optimize the scaling factor
    const result = optimize(objective, { bounds: [0.1, 10] });
    const bestScale = result.x;
    const bestScore = -result.fx;
    return [bestScore, bestScale];
};
//# sourceMappingURL=match_ascending_triangle.js.map